==> billboarder_0.2.6.tar.gz: billboarder/NEWS.md <==
billboarder 0.2.6
==================

* Upgrade billboard library to 1.8.0 (color on over, linear gradient for area charts, multiline text labels, bar width), see the [release note](https://medium.com/@alberto.park/billboard-js-1-8-0-released-today-3ed432f2d9d4)
* New function *bauge* : a gauge that automatically updates itself in Shiny apps.


billboarder 0.2.5
==================

* Upgrade billboard library to 1.7.0 (new theme, multiple axes, normalized staking data), see the [release note](https://medium.com/@alberto.park/billboard-js-1-7-0-release-4944a2eb59fe)



billboarder 0.2.4
==================

* Upgrade billboard library to 1.6.2
* New function `set_theme` to choose global theme for charts.



billboarder 0.2.3
==================

* Upgrade billboard library to 1.5.1
* Support for radar chart: `bb_radarchart`.
* Linked tooltip, see [this Gist](https://gist.github.com/pvictor/49fdb05d362acca8d6b94d69345a5046) for a demo.



billboarder 0.2.2
==================

* Upgrade billboard library to 1.4.1
* Support for `area-line-range` and `area-spline-range` in `bb_linechart`



billboarder 0.2.1
==================

* Upgrade billboard library to 1.2.0, and D3V4 to 4.12.2
* New proxy methods : `bb_proxy_data_colors` and `bb_proxy_data_names`.
* New aesthetic for scatterplots : `size`, to make bubble clouds.



billboarder 0.1.0
==================

* New charts type : lollipop, histogram and density plot.
* More methods for proxy and more examples, see `proxy_example` for more details.
* Upgrade to billboard.js 1.1.1.
* New functions `bbaes` and `bb_aes` to map data on chart, see the corresponding vignette.

==> billboarder_0.2.7.tar.gz: billboarder/NEWS.md <==
billboarder 0.2.7
==================

* Upgrade billboard library to 1.10.0, see the [release note](https://medium.com/@alberto.park/billboard-js-1-10-release-bubble-dimension-axis-culling-more-132d343a46cc)
* Upgrade billboard library to 1.9.0, see the [release note](https://medium.com/@alberto.park/billboard-js-1-9-release-introducing-plugins-more-636ada3a7881)

## Breaking changes

* Bubbles (when using `size` aesthetic in `bb_scatterplot`) are now computed in JavaScript, argument `range` is deprecated.



billboarder 0.2.6
==================

* Upgrade billboard library to 1.8.0 (color on over, linear gradient for area charts, multiline text labels, bar width), see the [release note](https://medium.com/@alberto.park/billboard-js-1-8-0-released-today-3ed432f2d9d4)
* New function *bauge* : a gauge that automatically updates itself in Shiny apps.


billboarder 0.2.5
==================

* Upgrade billboard library to 1.7.0 (new theme, multiple axes, normalized staking data), see the [release note](https://medium.com/@alberto.park/billboard-js-1-7-0-release-4944a2eb59fe)



billboarder 0.2.4
==================

* Upgrade billboard library to 1.6.2
* New function `set_theme` to choose global theme for charts.



billboarder 0.2.3
==================

* Upgrade billboard library to 1.5.1
* Support for radar chart: `bb_radarchart`.
* Linked tooltip, see [this Gist](https://gist.github.com/pvictor/49fdb05d362acca8d6b94d69345a5046) for a demo.



billboarder 0.2.2
==================

* Upgrade billboard library to 1.4.1
* Support for `area-line-range` and `area-spline-range` in `bb_linechart`



billboarder 0.2.1
==================

* Upgrade billboard library to 1.2.0, and D3V4 to 4.12.2
* New proxy methods : `bb_proxy_data_colors` and `bb_proxy_data_names`.
* New aesthetic for scatterplots : `size`, to make bubble clouds.



billboarder 0.1.0
==================

* New charts type : lollipop, histogram and density plot.
* More methods for proxy and more examples, see `proxy_example` for more details.
* Upgrade to billboard.js 1.1.1.
* New functions `bbaes` and `bb_aes` to map data on chart, see the corresponding vignette.
